summaryrefslogtreecommitdiff
path: root/libgfortran/generated/eoshift3_8.c
diff options
context:
space:
mode:
Diffstat (limited to 'libgfortran/generated/eoshift3_8.c')
-rw-r--r--libgfortran/generated/eoshift3_8.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/libgfortran/generated/eoshift3_8.c b/libgfortran/generated/eoshift3_8.c
index 2af1ccb9cf5..a90d87fcabf 100644
--- a/libgfortran/generated/eoshift3_8.c
+++ b/libgfortran/generated/eoshift3_8.c
@@ -89,7 +89,7 @@ eoshift3 (gfc_array_char * const restrict ret,
{
int i;
- ret->base_addr = internal_malloc_size (size * arraysize);
+ ret->base_addr = xmalloc (size * arraysize);
ret->offset = 0;
ret->dtype = array->dtype;
for (i = 0; i < GFC_DESCRIPTOR_RANK (array); i++)
@@ -107,8 +107,8 @@ eoshift3 (gfc_array_char * const restrict ret,
GFC_DIMENSION_SET(ret->dim[i], 0, ub, str);
}
- /* internal_malloc_size allocates a single byte for zero size. */
- ret->base_addr = internal_malloc_size (size * arraysize);
+ /* xmalloc allocates a single byte for zero size. */
+ ret->base_addr = xmalloc (size * arraysize);
}
else if (unlikely (compile_options.bounds_check))